@@ -4,12 +4,12 @@ from operator import mul
 
 import numpy as np
 
-from .core import Array
-from .utils import meta_from_array
 from ..base import tokenize
 from ..core import flatten
 from ..highlevelgraph import HighLevelGraph
 from ..utils import M
+from .core import Array
+from .utils import meta_from_array
 
 
 def reshape_rechunk(inshape, outshape, inchunks):
@@ -43,16 +43,26 @@ def reshape_rechunk(inshape, outshape, inchunks):
             if reduce(mul, inshape[ileft : ii + 1]) != dout:
                 raise ValueError("Shapes not compatible")
 
-            for i in range(ileft + 1, ii + 1):  # need single-shape dimensions
-                result_inchunks[i] = (inshape[i],)  # chunks[i] = (4,)
+            # Special case to avoid intermediate rechunking:
+            # When all the lower axis are completely chunked (chunksize=1) then
+            # we're simply moving around blocks.
+            if all(len(inchunks[i]) == inshape[i] for i in range(ii)):
+                for i in range(ii + 1):
+                    result_inchunks[i] = inchunks[i]
+                result_outchunks[oi] = inchunks[i] * np.prod(
+                    list(map(len, inchunks[:i]))
+                )
+            else:
+                for i in range(ileft + 1, ii + 1):  # need single-shape dimensions
+                    result_inchunks[i] = (inshape[i],)  # chunks[i] = (4,)
 
-            chunk_reduction = reduce(mul, map(len, inchunks[ileft + 1 : ii + 1]))
-            result_inchunks[ileft] = expand_tuple(inchunks[ileft], chunk_reduction)
+                chunk_reduction = reduce(mul, map(len, inchunks[ileft + 1 : ii + 1]))
+                result_inchunks[ileft] = expand_tuple(inchunks[ileft], chunk_reduction)
 
-            prod = reduce(mul, inshape[ileft + 1 : ii + 1])  # 16
-            result_outchunks[oi] = tuple(
-                prod * c for c in result_inchunks[ileft]
-            )  # (1, 1, 1, 1) .* 16
+                prod = reduce(mul, inshape[ileft + 1 : ii + 1])  # 16
+                result_outchunks[oi] = tuple(
+                    prod * c for c in result_inchunks[ileft]
+                )  # (1, 1, 1, 1) .* 16
 
             oi -= 1
             ii = ileft - 1
@@ -133,9 +143,24 @@ def contract_tuple(chunks, factor):
     return tuple(out)
 
 
-def reshape(x, shape):
+def reshape(x, shape, merge_chunks=True):
     """Reshape array to new shape
 
+    Parameters
+    ----------
+    shape : int or tuple of ints
+        The new shape should be compatible with the original shape. If
+        an integer, then the result will be a 1-D array of that length.
+        One shape dimension can be -1. In this case, the value is
+        inferred from the length of the array and remaining dimensions.
+    merge_chunks : bool, default True
+        Whether to merge chunks using the logic in :meth:`dask.array.rechunk`
+        when communication is necessary given the input array chunking and
+        the output shape. With ``merge_chunks==False``, the input array will
+        be rechunked to a chunksize of 1, which can create very many tasks.
+
+    Notes
+    -----
     This is a parallelized version of the ``np.reshape`` function with the
     following limitations:
 
@@ -148,6 +173,9 @@ def reshape(x, shape):
     When communication is necessary this algorithm depends on the logic within
     rechunk.  It endeavors to keep chunk sizes roughly the same when possible.
 
+    See :ref:`array-chunks.reshaping` for a discussion the tradeoffs of
+    ``merge_chunks``.
+
     See Also
     --------
     dask.array.rechunk
@@ -159,7 +187,7 @@ def reshape(x, shape):
     shape = tuple(map(sanitize_index, shape))
     known_sizes = [s for s in shape if s != -1]
     if len(known_sizes) < len(shape):
-        if len(known_sizes) - len(shape) > 1:
+        if len(shape) - len(known_sizes) > 1:
             raise ValueError("can only specify one unknown dimension")
         # Fastpath for x.reshape(-1) on 1D arrays, allows unknown shape in x
         # for this case only.
@@ -191,7 +219,12 @@ def reshape(x, shape):
         graph = HighLevelGraph.from_collections(name, dsk, dependencies=[x])
         return Array(graph, name, chunks, meta=meta)
 
-    # Logic for how to rechunk
+    # Logic or how to rechunk
+    din = len(x.shape)
+    dout = len(shape)
+    if not merge_chunks and din > dout:
+        x = x.rechunk({i: 1 for i in range(din - dout)})
+
     inchunks, outchunks = reshape_rechunk(x.shape, shape, x.chunks)
     x2 = x.rechunk(inchunks)
 
