@@ -1,12 +1,11 @@
-import pytest
 import numpy as np
+import pytest
 
 import dask.array as da
-from dask.array.utils import assert_eq, IS_NEP18_ACTIVE
+from dask.array.utils import IS_NEP18_ACTIVE, assert_eq
 
 from .test_dispatch import EncapsulateNDArray, WrappedArray
 
-
 missing_arrfunc_cond = not IS_NEP18_ACTIVE
 missing_arrfunc_reason = "NEP-18 support is not available in NumPy"
 
@@ -33,6 +32,8 @@ missing_arrfunc_reason = "NEP-18 support is not available in NumPy"
         lambda x: np.min(x),
         lambda x: np.amin(x),
         lambda x: np.round(x),
+        lambda x: np.insert(x, 0, 3, axis=0),
+        lambda x: np.delete(x, 0, axis=0),
     ],
 )
 def test_array_function_dask(func):
