@@ -1,13 +1,13 @@
 import random
+from copy import deepcopy
 from itertools import product
 
 import numpy as np
 import pytest
 
 import dask.array as da
-from dask.base import tokenize
 from dask.array.utils import assert_eq
-from copy import deepcopy
+from dask.base import tokenize
 
 pytest.importorskip("dask.array.ma")
 
@@ -32,12 +32,12 @@ def test_from_array_masked_array():
 def test_copy_deepcopy():
     t = np.ma.masked_array([1, 2], mask=[0, 1])
     x = da.from_array(t, chunks=t.shape, asarray=False)
-    #x = da.arange(5, chunks=(2,))
+    # x = da.arange(5, chunks=(2,))
     y = x.copy()
     memo = {}
     y2 = deepcopy(x, memo=memo)
 
-    xx = da.ma.masked_where([False, True], [1,2])
+    xx = da.ma.masked_where([False, True], [1, 2])
     assert_eq(x, xx)
 
     assert_eq(y, t)
@@ -51,7 +51,7 @@ functions = [
     lambda x: da.expm1(x),
     lambda x: 2 * x,
     lambda x: x / 2,
-    lambda x: x**2,
+    lambda x: x ** 2,
     lambda x: x + x,
     lambda x: x * x,
     lambda x: x[0],
@@ -77,7 +77,7 @@ functions = [
 ]
 
 
-@pytest.mark.parametrize('func', functions)
+@pytest.mark.parametrize("func", functions)
 def test_basic(func):
     x = da.random.random((2, 3, 4), chunks=(1, 2, 2))
     x[x < 0.4] = 0
@@ -103,15 +103,22 @@ def test_tensordot():
     xx = da.ma.masked_equal(x, 0)
     yy = da.ma.masked_equal(y, 0)
 
-    assert_eq(da.tensordot(x, y, axes=(2, 0)),
-              da.ma.filled(da.tensordot(xx, yy, axes=(2, 0)), 0))
-    assert_eq(da.tensordot(x, y, axes=(1, 1)),
-              da.ma.filled(da.tensordot(xx, yy, axes=(1, 1)), 0))
-    assert_eq(da.tensordot(x, y, axes=((1, 2), (1, 0))),
-              da.ma.filled(da.tensordot(xx, yy, axes=((1, 2), (1, 0))), 0))
+    assert_eq(
+        da.tensordot(x, y, axes=(2, 0)),
+        da.ma.filled(da.tensordot(xx, yy, axes=(2, 0)), 0),
+    )
+    assert_eq(
+        da.tensordot(x, y, axes=(1, 1)),
+        da.ma.filled(da.tensordot(xx, yy, axes=(1, 1)), 0),
+    )
+    assert_eq(
+        da.tensordot(x, y, axes=((1, 2), (1, 0))),
+        da.ma.filled(da.tensordot(xx, yy, axes=((1, 2), (1, 0))), 0),
+    )
 
 
-@pytest.mark.parametrize('func', functions)
+@pytest.mark.parametrize("func", functions)
+@pytest.mark.filterwarnings("ignore::numpy.ComplexWarning")  # abs() in assert_eq
 def test_mixed_concatenate(func):
     x = da.random.random((2, 3, 4), chunks=(1, 2, 2))
     y = da.random.random((2, 3, 4), chunks=(1, 2, 2))
@@ -124,10 +131,11 @@ def test_mixed_concatenate(func):
 
     dd = func(d)
     ss = func(s)
-    assert_eq(dd, ss)
+    assert_eq(dd, ss, check_meta=False)
 
 
-@pytest.mark.parametrize('func', functions)
+@pytest.mark.parametrize("func", functions)
+@pytest.mark.filterwarnings("ignore::numpy.ComplexWarning")  # abs() in assert_eq
 def test_mixed_random(func):
     d = da.random.random((4, 3, 4), chunks=(1, 2, 2))
     d[d < 0.4] = 0
@@ -138,7 +146,7 @@ def test_mixed_random(func):
     dd = func(d)
     ss = func(s)
 
-    assert_eq(dd, ss)
+    assert_eq(dd, ss, check_meta=False)
 
 
 def test_mixed_output_type():
@@ -192,7 +200,7 @@ def test_creation_functions():
     with pytest.raises(ValueError):
         da.ma.masked_values(dx, dy)
 
-    y = x.astype('f8')
+    y = x.astype("f8")
     y[0, 0] = y[7, 5] = np.nan
     dy = da.from_array(y, chunks=5)
 
@@ -201,8 +209,7 @@ def test_creation_functions():
     my = np.ma.masked_greater(y, 0)
     dmy = da.ma.masked_greater(dy, 0)
 
-    assert_eq(da.ma.fix_invalid(dmy, fill_value=0),
-              np.ma.fix_invalid(my, fill_value=0))
+    assert_eq(da.ma.fix_invalid(dmy, fill_value=0), np.ma.fix_invalid(my, fill_value=0))
 
 
 def test_filled():
@@ -218,17 +225,21 @@ def test_filled():
 
 def assert_eq_ma(a, b):
     res = a.compute()
-    assert type(res) == type(b)
-    if hasattr(res, 'mask'):
-        np.testing.assert_equal(res.mask, b.mask)
-        a = da.ma.filled(a)
-        b = np.ma.filled(b)
-    assert_eq(a, b, equal_nan=True)
+    if res is np.ma.masked:
+        assert res is b
+    else:
+        assert type(res) == type(b)
+        if hasattr(res, "mask"):
+            np.testing.assert_equal(res.mask, b.mask)
+            a = da.ma.filled(a)
+            b = np.ma.filled(b)
+        assert_eq(a, b, equal_nan=True)
 
 
-@pytest.mark.parametrize('dtype', ('i8', 'f8'))
-@pytest.mark.parametrize('reduction', ['sum', 'prod', 'mean', 'var', 'std',
-                                       'min', 'max', 'any', 'all'])
+@pytest.mark.parametrize("dtype", ("i8", "f8"))
+@pytest.mark.parametrize(
+    "reduction", ["sum", "prod", "mean", "var", "std", "min", "max", "any", "all"]
+)
 def test_reductions(dtype, reduction):
     x = (np.random.RandomState(42).rand(11, 11) * 10).astype(dtype)
     dx = da.from_array(x, chunks=(4, 4))
@@ -240,17 +251,34 @@ def test_reductions(dtype, reduction):
 
     assert_eq_ma(dfunc(mdx), func(mx))
     assert_eq_ma(dfunc(mdx, axis=0), func(mx, axis=0))
-    assert_eq_ma(dfunc(mdx, keepdims=True, split_every=4),
-                 func(mx, keepdims=True))
+    assert_eq_ma(dfunc(mdx, keepdims=True, split_every=4), func(mx, keepdims=True))
     assert_eq_ma(dfunc(mdx, axis=0, split_every=2), func(mx, axis=0))
-    assert_eq_ma(dfunc(mdx, axis=0, keepdims=True, split_every=2),
-                 func(mx, axis=0, keepdims=True))
+    assert_eq_ma(
+        dfunc(mdx, axis=0, keepdims=True, split_every=2),
+        func(mx, axis=0, keepdims=True),
+    )
     assert_eq_ma(dfunc(mdx, axis=1, split_every=2), func(mx, axis=1))
-    assert_eq_ma(dfunc(mdx, axis=1, keepdims=True, split_every=2),
-                 func(mx, axis=1, keepdims=True))
+    assert_eq_ma(
+        dfunc(mdx, axis=1, keepdims=True, split_every=2),
+        func(mx, axis=1, keepdims=True),
+    )
 
 
-@pytest.mark.parametrize('reduction', ['argmin', 'argmax'])
+@pytest.mark.parametrize("dtype", ("i8", "f8"))
+@pytest.mark.parametrize(
+    "reduction", ["sum", "prod", "mean", "var", "std", "min", "max", "any", "all"]
+)
+def test_reductions_allmasked(dtype, reduction):
+    x = np.ma.masked_array([1, 2], mask=True)
+    dx = da.from_array(x, asarray=False)
+
+    dfunc = getattr(da, reduction)
+    func = getattr(np, reduction)
+
+    assert_eq_ma(dfunc(dx), func(x))
+
+
+@pytest.mark.parametrize("reduction", ["argmin", "argmax"])
 def test_arg_reductions(reduction):
     x = np.random.random((10, 10, 10))
     dx = da.from_array(x, chunks=(3, 4, 5))
@@ -290,20 +318,27 @@ def test_accessors():
 
 
 def test_masked_array():
-    x = np.random.random((10, 10)).astype('f4')
+    x = np.random.random((10, 10)).astype("f4")
     dx = da.from_array(x, chunks=(3, 4))
     f1 = da.from_array(np.array(1), chunks=())
 
     fill_values = [(None, None), (0.5, 0.5), (1, f1)]
     for data, (df, f) in product([x, dx], fill_values):
-        assert_eq(da.ma.masked_array(data, fill_value=df),
-                  np.ma.masked_array(x, fill_value=f))
-        assert_eq(da.ma.masked_array(data, mask=data > 0.4, fill_value=df),
-                  np.ma.masked_array(x, mask=x > 0.4, fill_value=f))
-        assert_eq(da.ma.masked_array(data, mask=data > 0.4, fill_value=df),
-                  np.ma.masked_array(x, mask=x > 0.4, fill_value=f))
-        assert_eq(da.ma.masked_array(data, fill_value=df, dtype='f8'),
-                  np.ma.masked_array(x, fill_value=f, dtype='f8'))
+        assert_eq(
+            da.ma.masked_array(data, fill_value=df), np.ma.masked_array(x, fill_value=f)
+        )
+        assert_eq(
+            da.ma.masked_array(data, mask=data > 0.4, fill_value=df),
+            np.ma.masked_array(x, mask=x > 0.4, fill_value=f),
+        )
+        assert_eq(
+            da.ma.masked_array(data, mask=data > 0.4, fill_value=df),
+            np.ma.masked_array(x, mask=x > 0.4, fill_value=f),
+        )
+        assert_eq(
+            da.ma.masked_array(data, fill_value=df, dtype="f8"),
+            np.ma.masked_array(x, fill_value=f, dtype="f8"),
+        )
 
     with pytest.raises(ValueError):
         da.ma.masked_array(dx, fill_value=dx)
@@ -334,9 +369,7 @@ def test_set_fill_value():
 
 
 def test_average_weights_with_masked_array():
-    mask = np.array([[True, False],
-                     [True, True],
-                     [False, True]])
+    mask = np.array([[True, False], [True, True], [False, True]])
     data = np.arange(6).reshape((3, 2))
     a = np.ma.array(data, mask=mask)
     d_a = da.ma.masked_array(data=data, mask=mask, chunks=2)
@@ -351,9 +384,7 @@ def test_average_weights_with_masked_array():
 
 
 def test_arithmetic_results_in_masked():
-    mask = np.array([[True, False],
-                     [True, True],
-                     [False, True]])
+    mask = np.array([[True, False], [True, True], [False, True]])
     x = np.arange(6).reshape((3, 2))
     masked = np.ma.array(x, mask=mask)
     dx = da.from_array(x, chunks=(2, 2))
