@@ -1,7 +1,6 @@
+from .core import get_parallel_type, make_meta, meta_nonempty
 from .methods import concat_dispatch
-from .core import get_parallel_type, meta_nonempty, make_meta
-from .utils import hash_object_dispatch
-
+from .utils import group_split_dispatch, hash_object_dispatch
 
 ######################################
 # cuDF: Pandas Dataframes on the GPU #
@@ -10,6 +9,7 @@ from .utils import hash_object_dispatch
 
 @concat_dispatch.register_lazy("cudf")
 @hash_object_dispatch.register_lazy("cudf")
+@group_split_dispatch.register_lazy("cudf")
 @get_parallel_type.register_lazy("cudf")
 @meta_nonempty.register_lazy("cudf")
 @make_meta.register_lazy("cudf")
