@@ -1,20 +1,23 @@
 from collections import defaultdict
-import pandas as pd
-from tlz import partition_all
 from numbers import Integral
 
-from ..base import tokenize, compute_as_if_collection
+import pandas as pd
+from tlz import partition_all
+
+from ..base import compute_as_if_collection, tokenize
+from ..utils import Dispatch
+from . import methods
 from .accessor import Accessor
 from .utils import (
-    has_known_categories,
     clear_known_categories,
-    is_scalar,
+    has_known_categories,
     is_categorical_dtype,
+    is_scalar,
 )
 
 
 def _categorize_block(df, categories, index):
-    """ Categorize a dataframe with given categories
+    """Categorize a dataframe with given categories
 
     df: DataFrame
     categories: dict mapping column name to iterable of categories
@@ -24,12 +27,16 @@ def _categorize_block(df, categories, index):
         if is_categorical_dtype(df[col]):
             df[col] = df[col].cat.set_categories(vals)
         else:
-            df[col] = pd.Categorical(df[col], categories=vals, ordered=False)
+            cat_dtype = categorical_dtype(meta=df[col], categories=vals, ordered=False)
+            df[col] = df[col].astype(cat_dtype)
     if index is not None:
         if is_categorical_dtype(df.index):
             ind = df.index.set_categories(index)
         else:
-            ind = pd.Categorical(df.index, categories=index, ordered=False)
+            cat_dtype = categorical_dtype(
+                meta=df.index, categories=index, ordered=False
+            )
+            ind = df.index.astype(dtype=cat_dtype)
         ind.name = df.index.name
         df.index = ind
     return df
@@ -57,7 +64,10 @@ def _get_categories_agg(parts):
         for k, v in p[0].items():
             res[k].append(v)
         res_ind.append(p[1])
-    res = {k: pd.concat(v, ignore_index=True).drop_duplicates() for k, v in res.items()}
+    res = {
+        k: methods.concat(v, ignore_index=True).drop_duplicates()
+        for k, v in res.items()
+    }
     if res_ind[0] is None:
         return res, None
     return res, res_ind[0].append(res_ind[1:]).drop_duplicates()
@@ -264,3 +274,16 @@ class CategoricalAccessor(Accessor):
             meta=meta,
             token="cat-set_categories",
         )
+
+
+categorical_dtype_dispatch = Dispatch("CategoricalDtype")
+
+
+def categorical_dtype(meta, categories=None, ordered=False):
+    func = categorical_dtype_dispatch.dispatch(type(meta))
+    return func(categories=categories, ordered=ordered)
+
+
+@categorical_dtype_dispatch.register((pd.DataFrame, pd.Series, pd.Index))
+def categorical_dtype_pandas(categories=None, ordered=False):
+    return pd.api.types.CategoricalDtype(categories=categories, ordered=ordered)
