@@ -6,31 +6,30 @@ import warnings
 import numpy as np
 import pandas as pd
 
+from ..base import tokenize
+from ..highlevelgraph import HighLevelGraph
+from ..utils import M, derived_from, funcname, itemgetter
 from .core import (
     DataFrame,
     Series,
+    _extract_meta,
     aca,
     map_partitions,
     new_dd_object,
     no_default,
     split_out_on_index,
-    _extract_meta,
 )
-from .methods import drop_columns, concat
+from .methods import concat, drop_columns
 from .shuffle import shuffle
 from .utils import (
-    make_meta,
-    insert_meta_param_description,
-    raise_on_meta_error,
-    is_series_like,
-    is_dataframe_like,
     PANDAS_GT_100,
     PANDAS_GT_110,
+    insert_meta_param_description,
+    is_dataframe_like,
+    is_series_like,
+    make_meta,
+    raise_on_meta_error,
 )
-from ..base import tokenize
-from ..utils import derived_from, M, funcname, itemgetter
-from ..highlevelgraph import HighLevelGraph
-
 
 # #############################################
 #
@@ -216,7 +215,7 @@ def _groupby_get_group(df, by_key, get_key, columns):
 ###############################################################
 
 
-class Aggregation(object):
+class Aggregation:
     """User defined groupby-aggregation.
 
     This class allows users to define their own custom aggregation in terms of
@@ -470,7 +469,7 @@ def _cov_agg(_t, levels, ddof, std=False, sort=False):
     # when index is None we probably have selected a particular column
     # df.groupby('a')[['b']].cov()
     if len(idx_vals) == 1 and all(n is None for n in idx_vals):
-        idx_vals = list(set(inv_col_mapping.keys()) - set(total_sums.columns))
+        idx_vals = list(inv_col_mapping.keys() - set(total_sums.columns))
 
     for idx, val in enumerate(idx_vals):
         idx_name = inv_col_mapping.get(val, val)
@@ -1022,7 +1021,7 @@ def _cumcount_aggregate(a, b, fill_value=None):
     return a.add(b, fill_value=fill_value) + 1
 
 
-class _GroupBy(object):
+class _GroupBy:
     """Superclass for DataFrameGroupBy and SeriesGroupBy
 
     Parameters
