@@ -1,6 +1,6 @@
-from io import BytesIO
-import os
 import gzip
+import os
+from io import BytesIO
 from time import sleep
 from unittest import mock
 
@@ -9,24 +9,27 @@ import pytest
 pd = pytest.importorskip("pandas")
 dd = pytest.importorskip("dask.dataframe")
 
+from fsspec.compression import compr
 from tlz import partition_all, valmap
 
 import dask
 import dask.dataframe as dd
-from dask.dataframe._compat import tm
 from dask.base import compute_as_if_collection
-from dask.dataframe.io.csv import (
-    text_blocks_to_pandas,
-    pandas_read_text,
-    auto_blocksize,
-)
-from dask.dataframe.utils import assert_eq, has_known_categories
 from dask.bytes.core import read_bytes
 from dask.bytes.utils import compress
-from dask.utils import filetexts, filetext, tmpfile, tmpdir
-from fsspec.compression import compr
+from dask.core import flatten
+from dask.dataframe._compat import tm
+from dask.dataframe.io.csv import (
+    auto_blocksize,
+    block_mask,
+    pandas_read_text,
+    text_blocks_to_pandas,
+)
+from dask.dataframe.utils import assert_eq, has_known_categories
+from dask.utils import filetext, filetexts, tmpdir, tmpfile
 
-fmt_bs = [(fmt, None) for fmt in compr] + [(fmt, 10) for fmt in compr]
+# List of available compression format for test_read_csv_compression
+compression_fmts = [fmt for fmt in compr] + [None]
 
 
 def normalize_text(s):
@@ -180,16 +183,14 @@ def test_text_blocks_to_pandas_simple(reader, files):
     head = pandas_read_text(reader, files["2014-01-01.csv"], b"", {})
     header = files["2014-01-01.csv"].split(b"\n")[0] + b"\n"
 
-    df = text_blocks_to_pandas(reader, blocks, header, head, kwargs, collection=True)
+    df = text_blocks_to_pandas(reader, blocks, header, head, kwargs)
     assert isinstance(df, dd.DataFrame)
     assert list(df.columns) == ["name", "amount", "id"]
 
-    values = text_blocks_to_pandas(
-        reader, blocks, header, head, kwargs, collection=False
-    )
-    assert isinstance(values, list)
-    assert len(values) == 3
-    assert all(hasattr(item, "dask") for item in values)
+    values = text_blocks_to_pandas(reader, blocks, header, head, kwargs)
+    assert isinstance(values, dd.DataFrame)
+    assert hasattr(values, "dask")
+    assert len(values.dask) == 3
 
     assert_eq(df.amount.sum(), 100 + 200 + 300 + 400 + 500 + 600)
 
@@ -202,7 +203,7 @@ def test_text_blocks_to_pandas_kwargs(reader, files):
     head = pandas_read_text(reader, files["2014-01-01.csv"], b"", kwargs)
     header = files["2014-01-01.csv"].split(b"\n")[0] + b"\n"
 
-    df = text_blocks_to_pandas(reader, blocks, header, head, kwargs, collection=True)
+    df = text_blocks_to_pandas(reader, blocks, header, head, kwargs)
     assert list(df.columns) == ["name", "id"]
     result = df.compute()
     assert (result.columns == df.columns).all()
@@ -287,8 +288,8 @@ tsv_blocks = [
 def test_enforce_dtypes(reader, blocks):
     head = reader(BytesIO(blocks[0][0]), header=0)
     header = blocks[0][0].split(b"\n")[0] + b"\n"
-    dfs = text_blocks_to_pandas(reader, blocks, header, head, {}, collection=False)
-    dfs = dask.compute(*dfs, scheduler="sync")
+    dfs = text_blocks_to_pandas(reader, blocks, header, head, {})
+    dfs = dask.compute(dfs, scheduler="sync")
     assert all(df.dtypes.to_dict() == head.dtypes.to_dict() for df in dfs)
 
 
@@ -302,9 +303,7 @@ def test_enforce_columns(reader, blocks):
     head = reader(BytesIO(blocks[0][0]), header=0)
     header = blocks[0][0].split(b"\n")[0] + b"\n"
     with pytest.raises(ValueError):
-        dfs = text_blocks_to_pandas(
-            reader, blocks, header, head, {}, collection=False, enforce=True
-        )
+        dfs = text_blocks_to_pandas(reader, blocks, header, head, {}, enforce=True)
         dask.compute(*dfs, scheduler="sync")
 
 
@@ -453,8 +452,25 @@ def test_read_csv_include_path_column_is_dtype_category(dd_read, files):
         assert df.path.dtype == "category"
         assert has_known_categories(df.path)
 
-        dfs = dd_read("2014-01-*.csv", include_path_column=True, collection=False)
-        result = dfs[0].compute()
+        dfs = dd_read("2014-01-*.csv", include_path_column=True)
+        result = dfs.compute()
+        assert result.path.dtype == "category"
+        assert has_known_categories(result.path)
+
+
+@pytest.mark.parametrize(
+    "dd_read,files", [(dd.read_csv, csv_files), (dd.read_table, tsv_files)]
+)
+@read_table_mark
+def test_read_csv_include_path_column_with_multiple_partitions_per_file(dd_read, files):
+    with filetexts(files, mode="b"):
+        df = dd_read("2014-01-*.csv", blocksize="10B", include_path_column=True)
+        assert df.npartitions > 3
+        assert df.path.dtype == "category"
+        assert has_known_categories(df.path)
+
+        dfs = dd_read("2014-01-*.csv", blocksize="10B", include_path_column=True)
+        result = dfs.compute()
         assert result.path.dtype == "category"
         assert has_known_categories(result.path)
 
@@ -664,7 +680,8 @@ def test_categorical_known():
 
 
 @pytest.mark.slow
-def test_compression_multiple_files():
+@pytest.mark.parametrize("compression", ["infer", "gzip"])
+def test_compression_multiple_files(compression):
     with tmpdir() as tdir:
         f = gzip.open(os.path.join(tdir, "a.csv.gz"), "wb")
         f.write(csv_text.encode())
@@ -675,7 +692,7 @@ def test_compression_multiple_files():
         f.close()
 
         with pytest.warns(UserWarning):
-            df = dd.read_csv(os.path.join(tdir, "*.csv.gz"), compression="gzip")
+            df = dd.read_csv(os.path.join(tdir, "*.csv.gz"), compression=compression)
 
         assert len(df.compute()) == (len(csv_text.split("\n")) - 1) * 2
 
@@ -700,17 +717,22 @@ def test_read_csv_sensitive_to_enforce():
         assert a._name != b._name
 
 
-@pytest.mark.parametrize("fmt,blocksize", fmt_bs)
+@pytest.mark.parametrize("blocksize", [None, 10])
+@pytest.mark.parametrize("fmt", compression_fmts)
 def test_read_csv_compression(fmt, blocksize):
-    if fmt not in compress:
+    if fmt and fmt not in compress:
         pytest.skip("compress function not provided for %s" % fmt)
-    files2 = valmap(compress[fmt], csv_files)
-    with filetexts(files2, mode="b"):
+    suffix = {"gzip": ".gz", "bz2": ".bz2", "zip": ".zip", "xz": ".xz"}.get(fmt, "")
+    files2 = valmap(compress[fmt], csv_files) if fmt else csv_files
+    renamed_files = {k + suffix: v for k, v in files2.items()}
+    with filetexts(renamed_files, mode="b"):
+        # This test is using `compression="infer"` (the default) for
+        # read_csv.  The paths must have the appropriate extension.
         if fmt and blocksize:
             with pytest.warns(UserWarning):
-                df = dd.read_csv("2014-01-*.csv", compression=fmt, blocksize=blocksize)
+                df = dd.read_csv("2014-01-*.csv" + suffix, blocksize=blocksize)
         else:
-            df = dd.read_csv("2014-01-*.csv", compression=fmt, blocksize=blocksize)
+            df = dd.read_csv("2014-01-*.csv" + suffix, blocksize=blocksize)
         assert_eq(
             df.compute(scheduler="sync").reset_index(drop=True),
             expected.reset_index(drop=True),
@@ -829,6 +851,13 @@ def test_multiple_read_csv_has_deterministic_name():
         assert sorted(a.dask.keys(), key=str) == sorted(b.dask.keys(), key=str)
 
 
+def test_read_csv_has_different_names_based_on_blocksize():
+    with filetext(csv_text) as fn:
+        a = dd.read_csv(fn, blocksize="10kB")
+        b = dd.read_csv(fn, blocksize="20kB")
+        assert a._name != b._name
+
+
 def test_csv_with_integer_names():
     with filetext("alice,1\nbob,2") as fn:
         df = dd.read_csv(fn, header=None)
@@ -1552,3 +1581,53 @@ def test_to_csv_line_ending():
         with open(filename, "rb") as f:
             raw = f.read()
     assert raw in expected
+
+
+@pytest.mark.parametrize(
+    "block_lists",
+    [
+        [[1, 2], [3], [4, 5, 6]],
+        [],
+        [[], [], [1], [], [1]],
+        [list(range(i)) for i in range(10)],
+    ],
+)
+def test_block_mask(block_lists):
+    mask = list(block_mask(block_lists))
+    assert len(mask) == len(list(flatten(block_lists)))
+
+
+def test_reading_empty_csv_files_with_path():
+    with tmpdir() as tdir:
+        for k, content in enumerate(["0, 1, 2", "", "6, 7, 8"]):
+            with open(os.path.join(tdir, str(k) + ".csv"), "w") as file:
+                file.write(content)
+        result = dd.read_csv(
+            os.path.join(tdir, "*.csv"),
+            include_path_column=True,
+            converters={"path": parse_filename},
+            names=["A", "B", "C"],
+        ).compute()
+        df = pd.DataFrame(
+            {
+                "A": [0, 6],
+                "B": [1, 7],
+                "C": [2, 8],
+                "path": ["0.csv", "2.csv"],
+            }
+        )
+        df["path"] = df["path"].astype("category")
+        assert_eq(result, df, check_index=False)
+
+
+def test_read_csv_groupby_get_group(tmpdir):
+    # https://github.com/dask/dask/issues/7005
+
+    path = os.path.join(str(tmpdir), "test.csv")
+    df1 = pd.DataFrame([{"foo": 10, "bar": 4}])
+    df1.to_csv(path, index=False)
+
+    ddf1 = dd.read_csv(path)
+    ddfs = ddf1.groupby("foo")
+
+    assert_eq(df1, ddfs.get_group(10).compute())
