@@ -5,9 +5,9 @@ from distutils.version import LooseVersion
 
 import pytest
 
+import dask.dataframe as dd
 from dask.dataframe import read_orc
 from dask.dataframe.utils import assert_eq
-import dask.dataframe as dd
 
 pytest.importorskip("pyarrow.orc")
 
@@ -35,7 +35,7 @@ columns = ["time", "date"]
 def test_orc_with_backend():
     pytest.importorskip("requests")
     d = read_orc(url)
-    assert set(d.columns) == {"time", "date"}  # order is not guranteed
+    assert set(d.columns) == {"time", "date"}  # order is not guaranteed
     assert len(d) == 70000
 
 
