@@ -5,14 +5,14 @@ import pandas as pd
 from pandas.api.types import is_categorical_dtype, union_categoricals
 from tlz import partition
 
-from .utils import (
-    is_series_like,
-    is_index_like,
-    is_dataframe_like,
-    hash_object_dispatch,
-    group_split_dispatch,
-)
 from ..utils import Dispatch
+from .utils import (
+    group_split_dispatch,
+    hash_object_dispatch,
+    is_dataframe_like,
+    is_index_like,
+    is_series_like,
+)
 
 # ---------------------------------
 # indexing
@@ -416,8 +416,11 @@ def concat(
         True if all arguments have the same columns and dtypes (but not
         necessarily categories). Default is False.
     ignore_index : bool, optional
-        Whether to allow index values to be ignored/droped during
+        Whether to allow index values to be ignored/dropped during
         concatenation. Default is False.
+    ignore_order : bool, optional
+        Whether to ignore the order when doing the union of categoricals.
+        Default is False.
     """
     if len(dfs) == 1:
         return dfs[0]
@@ -444,6 +447,8 @@ def concat_pandas(
     ignore_index=False,
     **kwargs
 ):
+    ignore_order = kwargs.pop("ignore_order", False)
+
     if axis == 1:
         return pd.concat(dfs, axis=axis, join=join, **kwargs)
 
@@ -453,7 +458,9 @@ def concat_pandas(
             for i in range(1, len(dfs)):
                 if not isinstance(dfs[i], pd.CategoricalIndex):
                     dfs[i] = dfs[i].astype("category")
-            return pd.CategoricalIndex(union_categoricals(dfs), name=dfs[0].name)
+            return pd.CategoricalIndex(
+                union_categoricals(dfs, ignore_order=ignore_order), name=dfs[0].name
+            )
         elif isinstance(dfs[0], pd.MultiIndex):
             first, rest = dfs[0], dfs[1:]
             if all(
@@ -545,7 +552,7 @@ def concat_pandas(
                             codes, sample.cat.categories, sample.cat.ordered
                         )
                         parts.append(data)
-                out[col] = union_categoricals(parts)
+                out[col] = union_categoricals(parts, ignore_order=ignore_order)
                 # Pandas resets index type on assignment if frame is empty
                 # https://github.com/pandas-dev/pandas/issues/17101
                 if not len(temp_ind):
@@ -562,7 +569,11 @@ def concat_pandas(
         if is_categorical_dtype(dfs2[0].dtype):
             if ind is None:
                 ind = concat([df.index for df in dfs2])
-            return pd.Series(union_categoricals(dfs2), index=ind, name=dfs2[0].name)
+            return pd.Series(
+                union_categoricals(dfs2, ignore_order=ignore_order),
+                index=ind,
+                name=dfs2[0].name,
+            )
         with warnings.catch_warnings():
             if filter_warning:
                 warnings.simplefilter("ignore", FutureWarning)
